import { BasicColumn, FormSchema } from '/@/components/Table';
import { h, unref } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '/@/hooks/web/useMessage';
import { RouteTypeStatus, setRouteStatus } from '/@/api/tigerapi/mes/router';
import { useI18n } from '/@/hooks/web/useI18n';
import { useLocale } from '/@/locales/useLocale';

const { t } = useI18n();
const { getLocale } = useLocale();

export const columns: BasicColumn[] = [
  {
    title: '工艺路线编码',
    dataIndex: 'ROT_CODE',
    width: 200,
  },
  {
    title: '工艺路线名称',
    dataIndex: 'ROT_NAME',
    width: 180,
  },
  {
    title: '状态',
    dataIndex: 'IS_ACTIVE',
    width: 120,
    customRender: ({ record }) => {
      if (!Reflect.has(record, 'pendingStatus')) {
        record.pendingStatus = false;
      }
      return h(Switch, {
        checked: record.IS_ACTIVE === 'Y',
        checkedChildren: '已启用',
        unCheckedChildren: '已禁用',
        loading: record.pendingStatus,
        onChange(checked: boolean) {
          const oldStatus = record.IS_ACTIVE;
          record.pendingStatus = true;
          const newStatus = checked ? 'Y' : 'N';
          console.log(10, newStatus);
          const { createMessage } = useMessage();
          record.IS_ACTIVE = newStatus;
          setRouteStatus(record)
            .then(() => {
              createMessage.success(`已成功修改工艺路线状态`);
            })
            .catch(() => {
              createMessage.error('修改工艺路线状态失败');
              record.IS_ACTIVE = oldStatus;
            })
            .finally(() => {
              record.pendingStatus = false;
            });
        },
      });
    },
    editDynamicDisabled: true,
  },
  {
    title: '创建时间',
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'REMARK',
    width: 180,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'ROT_CODE',
    label: '工艺路线编码',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ROT_NAME',
    label: '工艺路线名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'IS_ACTIVE',
    label: '状态',
    component: 'Select',
    componentProps: {
      options: [
        { label: '启用', value: 'Y' },
        { label: '停用', value: 'N' },
      ],
    },
    colProps: { span: 8 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'ROT_CODE',
    label: '工艺路线编码',
    required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'ROT_NAME',
    label: '工艺路线名称',
    required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    field: 'ROT_TYPE',
    label: t('工艺路线类型'),
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: RouteTypeStatus,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
  },
  {
    field: 'ROT_VER',
    label: '工艺路线版本',
    // required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    field: 'IS_ACTIVE',
    label: '是否启用(Y/N)',
    required: true,
    component: 'Select',
    colProps: { span: 24 },
    componentProps: {
      options: [
        {
          label: '是',
          value: 'Y',
          key: 'Y',
        },
        {
          label: '否',
          value: 'N',
          key: 'N',
        },
      ],
    },
  },
  {
    field: 'REMARK',
    label: '备注',
    // required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
];
